r"""
Features for testing the presence of ``graphviz``
"""

# ****************************************************************************
#       Copyright (C) 2018 Sebastien Labbe <slabqc@gmail.com>
#                     2021 Matthias Koeppe
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#                  https://www.gnu.org/licenses/
# ****************************************************************************

from . import Executable
from .join_feature import JoinFeature


class dot(Executable):
    r"""
    A :class:`~sage.features.Feature` describing the presence of ``dot``.

    TESTS::

        sage: from sage.features.graphviz import dot
        sage: dot().is_present()  # optional - graphviz
        FeatureTestResult('dot', True)
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.graphviz import dot
            sage: isinstance(dot(), dot)
            True
        """
        Executable.__init__(self, "dot", executable="dot",
                            spkg="graphviz",
                            url="https://www.graphviz.org/")


class neato(Executable):
    r"""
    A :class:`~sage.features.Feature` describing the presence of ``neato``.

    TESTS:

        sage: from sage.features.graphviz import neato
        sage: neato().is_present()  # optional - graphviz
        FeatureTestResult('neato', True)
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.graphviz import neato
            sage: isinstance(neato(), neato)
            True
        """
        Executable.__init__(self, "neato", executable="neato",
                            spkg="graphviz",
                            url="https://www.graphviz.org/")


class twopi(Executable):
    r"""
    A :class:`~sage.features.Feature` describing the presence of ``twopi``.

    TESTS::

        sage: from sage.features.graphviz import twopi
        sage: twopi().is_present()  # optional - graphviz
        FeatureTestResult('twopi', True)
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.graphviz import twopi
            sage: isinstance(twopi(), twopi)
            True
        """
        Executable.__init__(self, "twopi", executable="twopi",
                            spkg="graphviz",
                            url="https://www.graphviz.org/")


class Graphviz(JoinFeature):
    r"""
    A :class:`~sage.features.Feature` describing the presence of
    the :class:`dot`, :class:`neato`, and :class:`twopi` executables from the
    :ref:`graphviz <spkg_graphviz>` package.

    EXAMPLES::

        sage: from sage.features.graphviz import Graphviz
        sage: Graphviz().is_present()  # optional - graphviz
        FeatureTestResult('graphviz', True)
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.graphviz import Graphviz
            sage: isinstance(Graphviz(), Graphviz)
            True
        """
        JoinFeature.__init__(self, "graphviz",
                             [dot(), neato(), twopi()],
                             spkg="graphviz",
                             url="https://www.graphviz.org/")


def all_features():
    return [Graphviz()]



r"""
Features for testing the presence of ``gfan``
"""

# *****************************************************************************
#       Copyright (C) 2022 Matthias Koeppe
#
#  Distributed under the terms of the GNU General Public License (GPL)
#  as published by the Free Software Foundation; either version 2 of
#  the License, or (at your option) any later version.
#                  https://www.gnu.org/licenses/
# *****************************************************************************

from . import Executable


class GfanExecutable(Executable):
    r"""
    A :class:`~sage.features.Feature` for the :ref:`gfan <spkg_gfan>` executables.
    """
    def __init__(self, cmd=None):
        r"""
        TESTS::

            sage: from sage.features.gfan import GfanExecutable
            sage: isinstance(GfanExecutable('groebnercone'), GfanExecutable)
            True
        """
        if cmd is None:
            name = "gfan"
        else:
            name = f"gfan_{cmd}"
        Executable.__init__(self, name, executable=name, spkg="gfan", type='standard')


def all_features():
    return [GfanExecutable()]



r"""
Features for testing the presence of :class:`MixedIntegerLinearProgram` backends
"""

# *****************************************************************************
#       Copyright (C) 2021-2022 Matthias Koeppe
#                     2021      Kwankyu Lee
#
#  Distributed under the terms of the GNU General Public License (GPL)
#  as published by the Free Software Foundation; either version 2 of
#  the License, or (at your option) any later version.
#                  https://www.gnu.org/licenses/
# *****************************************************************************

from . import Feature, PythonModule, FeatureTestResult
from .join_feature import JoinFeature


class MIPBackend(Feature):
    r"""
    A :class:`~sage.features.Feature` describing whether a :class:`MixedIntegerLinearProgram` backend is available.
    """
    def _is_present(self):
        r"""
        Test for the presence of a :class:`MixedIntegerLinearProgram` backend.

        EXAMPLES::

            sage: from sage.features.mip_backends import CPLEX
            sage: CPLEX()._is_present()  # optional - cplex
            FeatureTestResult('cplex', True)
        """
        try:
            from sage.numerical.mip import MixedIntegerLinearProgram
            MixedIntegerLinearProgram(solver=self.name)
            return FeatureTestResult(self, True)
        except Exception:
            return FeatureTestResult(self, False)


class CPLEX(MIPBackend):
    r"""
    A :class:`~sage.features.Feature` describing whether the :class:`MixedIntegerLinearProgram` backend ``CPLEX`` is available.
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.mip_backends import CPLEX
            sage: CPLEX()._is_present()  # optional - cplex
            FeatureTestResult('cplex', True)
        """
        MIPBackend.__init__(self, 'cplex',
                            spkg='sage_numerical_backends_cplex')


class Gurobi(MIPBackend):
    r"""
    A :class:`~sage.features.Feature` describing whether the :class:`MixedIntegerLinearProgram` backend ``Gurobi`` is available.
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.mip_backends import Gurobi
            sage: Gurobi()._is_present()  # optional - gurobi
            FeatureTestResult('gurobi', True)
        """
        MIPBackend.__init__(self, 'gurobi',
                            spkg='sage_numerical_backends_gurobi')


class COIN(JoinFeature):
    r"""
    A :class:`~sage.features.Feature` describing whether the :class:`MixedIntegerLinearProgram` backend ``COIN`` is available.
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.mip_backends import COIN
            sage: COIN()._is_present()  # optional - sage_numerical_backends_coin
            FeatureTestResult('sage_numerical_backends_coin', True)
        """
        JoinFeature.__init__(self, 'sage_numerical_backends_coin',
                             [MIPBackend('coin')],
                             spkg='sage_numerical_backends_coin')


class CVXOPT(JoinFeature):
    r"""
    A :class:`~sage.features.Feature` describing whether the :class:`MixedIntegerLinearProgram` backend ``CVXOPT`` is available.
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.mip_backends import CVXOPT
            sage: CVXOPT()._is_present()  # optional - cvxopt
            FeatureTestResult('cvxopt', True)
        """
        JoinFeature.__init__(self, 'cvxopt',
                             [MIPBackend('CVXOPT'),
                              PythonModule('cvxopt')],
                             spkg='cvxopt',
                             type='standard')


def all_features():
    return [CPLEX(),
            Gurobi(),
            COIN(),
            CVXOPT()]



# Sage version information for Python scripts
# This file is auto-generated by the sage-update-version script, do not edit!
version = '10.3.rc4'
date = '2024-03-17'
banner = 'SageMath version 10.3.rc4, Release Date: 2024-03-17'



# -*- coding: utf-8 -*-
r"""
Feature for testing the presence of ``pandoc``
"""
# ****************************************************************************
#       Copyright (C) 2018 Thierry Monteil <sage!lma.metelu.net>
#                     2021 Matthias Koeppe
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#                  https://www.gnu.org/licenses/
# ****************************************************************************

from . import Executable


class Pandoc(Executable):
    r"""
    A :class:`~sage.features.Feature` describing the presence of :ref:`pandoc <spkg_pandoc>`.

    EXAMPLES::

        sage: from sage.features.pandoc import Pandoc
        sage: Pandoc().is_present()  # optional - pandoc
        FeatureTestResult('pandoc', True)
    """
    def __init__(self):
        r"""
        TESTS::

            sage: from sage.features.pandoc import Pandoc
            sage: isinstance(Pandoc(), Pandoc)
            True
        """
        Executable.__init__(self, "pandoc", executable="pandoc",
                            url="https://pandoc.org/")


def all_features():
    return [Pandoc()]
